@@ -622,6 +622,12 @@ def setup_parser():
     ###                    Project options                ###
     #########################################################
 
+    # TEST: add a subcommand that should not be rendered in the output
+    parser_whoami = subparsers.add_parser(
+        "hidden",
+        help=argparse.SUPPRESS,
+    )
+
     parser_whoami = subparsers.add_parser(
         "whoami",
         help="Print username that the client authenticates with against copr-frontend"
@@ -971,13 +977,13 @@ def setup_parser():
                                        metavar="PKGNAME", required=True)
     parser_delete_package.set_defaults(func="action_delete_package")
 
-    # package reseting
+    # package resetting
     parser_reset_package = subparsers.add_parser("reset-package",
                                                  help="Resets (clears) default source of the specified package")
     parser_reset_package.add_argument("copr",
                                       help="The copr repo to list the packages of. Can be just name of project or even in format owner/project.")
     parser_reset_package.add_argument("--name",
-                                      help="Name of a package to be reseted",
+                                      help="Name of a package to be reset",
                                       metavar="PKGNAME", required=True)
     parser_reset_package.set_defaults(func="action_reset_package")
 
